@@ -32,6 +32,39 @@ def postgres_engine_factory(args: Dict[str, str]) -> Engine:
     return create_engine(conn_string, connect_args={"sslcompression": 0})
 
 
+def bizible_snowflake_engine_factory(
+    args: Dict[str, str], role: str, schema: str = ""
+) -> Engine:
+    """
+    Create a database engine from a dictionary of database info.
+    Separate convenience function for bizible as it would create a strange conditional in the general function.
+    """
+    role_dict = {
+        # Note: This Bizible user is used for extracting data from Bizible
+        "BIZIBLE_USER": {
+            "USER": "BIZIBLE_SNOWFLAKE_USER",
+            "PASSWORD": "BIZIBLE_SNOWFLAKE_PASSWORD",
+            "ACCOUNT": "BIZIBLE_SNOWFLAKE_ACCOUNT",
+            "DATABASE": "BIZIBLE_SNOWFLAKE_DATABASE",
+            "WAREHOUSE": "BIZIBLE_SNOWFLAKE_WAREHOUSE",
+            "ROLE": "BIZIBLE_SNOWFLAKE_ROLE",
+        }
+    }
+    vars_dict = role_dict[role]
+
+    conn_string = snowflake_URL(
+        user=args[vars_dict["USER"]],
+        password=args[vars_dict["PASSWORD"]],
+        account=args[vars_dict["ACCOUNT"]],
+        database=args[vars_dict["DATABASE"]],
+        warehouse=args[vars_dict["WAREHOUSE"]],
+        role=args[vars_dict["ROLE"]],
+        schema=schema,
+    )
+
+    return create_engine(conn_string, connect_args={"sslcompression": 0})
+
+
 def snowflake_engine_factory(
     args: Dict[str, str], role: str, schema: str = ""
 ) -> Engine:
@@ -55,7 +88,7 @@ def snowflake_engine_factory(
             "ACCOUNT": "SNOWFLAKE_ACCOUNT",
             "DATABASE": "SNOWFLAKE_PROD_DATABASE",
             "WAREHOUSE": "SNOWFLAKE_LOAD_WAREHOUSE",
-            "ROLE": "LOADER",
+            "ROLE": "DATA_SCIENCE_LOADER",
         },
         "LOADER": {
             "USER": "SNOWFLAKE_LOAD_USER",
@@ -73,15 +106,6 @@ def snowflake_engine_factory(
             "WAREHOUSE": "SNOWFLAKE_TRANSFORM_WAREHOUSE",
             "ROLE": "TRANSFORMER",
         },
-        # Note: This Bizible user is used for extracting data from Bizible
-        "BIZIBLE_USER": {
-            "USER": "BIZIBLE_SNOWFLAKE_USER",
-            "PASSWORD": "BIZIBLE_SNOWFLAKE_PASSWORD",
-            "ACCOUNT": "BIZIBLE_SNOWFLAKE_ACCOUNT",
-            "DATABASE": "BIZIBLE_SNOWFLAKE_DATABASE",
-            "WAREHOUSE": "BIZIBLE_SNOWFLAKE_WAREHOUSE",
-            "ROLE": "BIZIBLE_SNOWFLAKE_ROLE",
-        },
     }
 
     vars_dict = role_dict[role]
@@ -252,7 +276,7 @@ def snowflake_stage_load_copy_remove(
     Upload file to stage, copy to table, remove file from stage on Snowflake
     """
 
-    put_query = f"put file://{file} @{stage} auto_compress=true;"
+    put_query = f"put 'file://{file}' @{stage} auto_compress=true;"
 
     if type == "json":
         copy_query = f"""copy into {table_path} (jsontext)
